@@ -3,7 +3,7 @@
 # Comments - A class for writing the Excel XLSX Worksheet file.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2022, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
 #
 
 from . import xmlwriter
@@ -54,7 +54,7 @@ class Comments(xmlwriter.XMLwriter):
         # Write the commentList element.
         self._write_comment_list(comments_data)
 
-        self._xml_end_tag('comments')
+        self._xml_end_tag("comments")
 
         # Close the file.
         self._xml_close()
@@ -67,17 +67,17 @@ class Comments(xmlwriter.XMLwriter):
 
     def _write_comments(self):
         # Write the <comments> element.
-        xmlns = 'http://schemas.openxmlformats.org/spreadsheetml/2006/main'
+        xmlns = "http://schemas.openxmlformats.org/spreadsheetml/2006/main"
 
-        attributes = [('xmlns', xmlns)]
+        attributes = [("xmlns", xmlns)]
 
-        self._xml_start_tag('comments', attributes)
+        self._xml_start_tag("comments", attributes)
 
     def _write_authors(self, comment_data):
         # Write the <authors> element.
         author_count = 0
 
-        self._xml_start_tag('authors')
+        self._xml_start_tag("authors")
 
         for comment in comment_data:
             author = comment[3]
@@ -90,15 +90,15 @@ class Comments(xmlwriter.XMLwriter):
                 # Write the author element.
                 self._write_author(author)
 
-        self._xml_end_tag('authors')
+        self._xml_end_tag("authors")
 
     def _write_author(self, data):
         # Write the <author> element.
-        self._xml_data_element('author', data)
+        self._xml_data_element("author", data)
 
     def _write_comment_list(self, comment_data):
         # Write the <commentList> element.
-        self._xml_start_tag('commentList')
+        self._xml_start_tag("commentList")
 
         for comment in comment_data:
             row = comment[0]
@@ -118,36 +118,36 @@ class Comments(xmlwriter.XMLwriter):
             font = (font_name, font_size, font_family)
             self._write_comment(row, col, text, author_id, font)
 
-        self._xml_end_tag('commentList')
+        self._xml_end_tag("commentList")
 
     def _write_comment(self, row, col, text, author_id, font):
         # Write the <comment> element.
         ref = xl_rowcol_to_cell(row, col)
 
-        attributes = [('ref', ref)]
+        attributes = [("ref", ref)]
 
         if author_id is not None:
-            attributes.append(('authorId', author_id))
+            attributes.append(("authorId", author_id))
 
-        self._xml_start_tag('comment', attributes)
+        self._xml_start_tag("comment", attributes)
 
         # Write the text element.
         self._write_text(text, font)
 
-        self._xml_end_tag('comment')
+        self._xml_end_tag("comment")
 
     def _write_text(self, text, font):
         # Write the <text> element.
-        self._xml_start_tag('text')
+        self._xml_start_tag("text")
 
         # Write the text r element.
         self._write_text_r(text, font)
 
-        self._xml_end_tag('text')
+        self._xml_end_tag("text")
 
     def _write_text_r(self, text, font):
         # Write the <r> element.
-        self._xml_start_tag('r')
+        self._xml_start_tag("r")
 
         # Write the rPr element.
         self._write_r_pr(font)
@@ -155,20 +155,20 @@ class Comments(xmlwriter.XMLwriter):
         # Write the text r element.
         self._write_text_t(text)
 
-        self._xml_end_tag('r')
+        self._xml_end_tag("r")
 
     def _write_text_t(self, text):
         # Write the text <t> element.
         attributes = []
 
         if preserve_whitespace(text):
-            attributes.append(('xml:space', 'preserve'))
+            attributes.append(("xml:space", "preserve"))
 
-        self._xml_data_element('t', text, attributes)
+        self._xml_data_element("t", text, attributes)
 
     def _write_r_pr(self, font):
         # Write the <rPr> element.
-        self._xml_start_tag('rPr')
+        self._xml_start_tag("rPr")
 
         # Write the sz element.
         self._write_sz(font[1])
@@ -182,28 +182,28 @@ class Comments(xmlwriter.XMLwriter):
         # Write the family element.
         self._write_family(font[2])
 
-        self._xml_end_tag('rPr')
+        self._xml_end_tag("rPr")
 
     def _write_sz(self, font_size):
         # Write the <sz> element.
-        attributes = [('val', font_size)]
+        attributes = [("val", font_size)]
 
-        self._xml_empty_tag('sz', attributes)
+        self._xml_empty_tag("sz", attributes)
 
     def _write_color(self):
         # Write the <color> element.
-        attributes = [('indexed', 81)]
+        attributes = [("indexed", 81)]
 
-        self._xml_empty_tag('color', attributes)
+        self._xml_empty_tag("color", attributes)
 
     def _write_r_font(self, font_name):
         # Write the <rFont> element.
-        attributes = [('val', font_name)]
+        attributes = [("val", font_name)]
 
-        self._xml_empty_tag('rFont', attributes)
+        self._xml_empty_tag("rFont", attributes)
 
     def _write_family(self, font_family):
         # Write the <family> element.
-        attributes = [('val', font_family)]
+        attributes = [("val", font_family)]
 
-        self._xml_empty_tag('family', attributes)
+        self._xml_empty_tag("family", attributes)
